@@ -38,8 +38,12 @@ class AutocompleteRegistry(dict):
     Dict with some shortcuts to handle a registry of autocompletes.
     """
 
-    def __init__(self):
+    def __init__(self, autocomplete_model_base=None):
         self._models = {}
+        self.autocomplete_model_base = autocomplete_model_base
+
+        if self.autocomplete_model_base is None:
+            self.autocomplete_model_base = AutocompleteModelBase
 
     def autocomplete_for_model(self, model):
         """ Return the autocomplete class for a given model. """
@@ -59,6 +63,19 @@ class AutocompleteRegistry(dict):
         except AttributeError:
             pass
 
+    @classmethod
+    def extract_args(cls, *args):
+        model = None
+        autocomplete = None
+
+        for arg in args:
+            if issubclass(arg, models.Model):
+                model = arg
+            else:
+                autocomplete = arg
+
+        return [model, autocomplete]
+
     def register(self, *args, **kwargs):
         """
         Register an autocomplete.
@@ -75,17 +92,10 @@ class AutocompleteRegistry(dict):
         thread safety reasons, a copy of the autocomplete class is stored in
         the registry.
         """
-        autocomplete = None
-        model = None
-
         assert len(args) <= 2, 'register takes at most 2 args'
         assert len(args) > 0, 'register takes at least 1 arg'
 
-        for arg in args:
-            if issubclass(arg, models.Model):
-                model = arg
-            else:
-                autocomplete = arg
+        model, autocomplete = self.__class__.extract_args(*args)
 
         if not model:
             try:
@@ -114,7 +124,7 @@ class AutocompleteRegistry(dict):
             name = '%sAutocomplete' % model.__name__
 
         if autocomplete is None:
-            base = AutocompleteModelBase
+            base = self.autocomplete_model_base
         else:
             base = autocomplete
 
